//
//  TEBeautyLiveAdapter.h
//  TELiveAdapter
//
//  Created by tao yue on 2024/4/21.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
@class TEBeautyKit;
@class XMagic;

typedef void (^OnCreatedTEBeautyKit)(TEBeautyKit * _Nullable beautyKit, XMagic * _Nullable xmagicApi);
typedef void(^OnDestroyTEBeautyKit)(void);

typedef NS_ENUM(NSUInteger, TEAdapterImageStartPosition) {
    TOP,
    RIGHT,
    BOTTOM,
    LEFT,
};

typedef NS_ENUM(NSUInteger, VideoMirrorType) {
    VIDEO_MIRROR_TYPE_AUTO,  //自动模式：如果正使用前置摄像头则开启镜像，如果是后置摄像头则不开启镜像（仅适用于移动设备）
    VIDEO_MIRROR_TYPE_ENABLE,  //强制开启镜像，不论当前使用的是前置摄像头还是后置摄像头
    VIDEO_MIRROR_TYPE_DISABLE  //强制关闭镜像，不论当前使用的是前置摄像头还是后置摄像头
};

@interface TEBeautyLiveAdapter : NSObject

/**
 * 将美颜与（TRTCCloud或livePusher）进行绑定
 *
 * @param pusher   TRTCCloud或者V2TXLivePusher
 * @param onCreatedTEBeautyKit  绑定成功之后的回调，会返回美颜对象
 * @param onDestroyTEBeautyKit  解除绑定之后的回调
 */
-(void)bind:(id _Nonnull)pusher onCreatedTEBeautyKit:(OnCreatedTEBeautyKit _Nullable)onCreatedTEBeautyKit onDestroyTEBeautyKit:(OnDestroyTEBeautyKit _Nullable)onDestroyTEBeautyKit;

/**
 * 解除绑定
 */
-(void)unbind;

/**
 * 当ViewController 的方向改变的时候调用。
 *
 * @param orientation ViewController 的方向
 */
-(void)setDeviceOrientation:(UIDeviceOrientation)orientation;

/**
 * 美颜特效的起始方向，默认是TOP。
 *
 * @param orientation 美颜特效 的方向
 */
-(void)setImageStartPosition:(TEAdapterImageStartPosition)orientation;

/**
 * 当前后摄像头切换的时候调用此方法通知adapter
 *
 * @param isFrontCamera   是否是前置摄像头
 * @param mirrorType  是否镜像
 */
-(void)notifyCameraChanged:(BOOL)isFrontCamera mirrorType:(VideoMirrorType)mirrorType;


@end

